@@ -1,7 +1,7 @@
 package Log::ger::Format::Block;
 
-our $DATE = '2017-06-23'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-06-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -56,7 +56,7 @@ Log::ger::Format::Block - Use formatting using block instead of sprintf-style
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -71,11 +71,13 @@ After that, you can use your logging routine a la L<Log::Contextual>:
 To install only for current package:
 
  use Log::ger::Format;
- Log::ger->set_for_current_package('Block');
+ BEGIN { Log::ger->set_for_current_package('Block') }
  use Log::ger;
 
 =head1 DESCRIPTION
 
+Caveat: you have to do this in the compile-time phase (like shown in Synopsis).
+
 =for Pod::Coverage ^(.+)$
 
 =head1 SEE ALSO
